@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -43,7 +43,8 @@
 //#define DEBUG_SENDLATERAGENT 1
 
 SendLaterAgent::SendLaterAgent(const QString &id)
-    : Akonadi::AgentBase( id )
+    : Akonadi::AgentBase( id ),
+      mAgentInitialized(false)
 {
     mManager = new SendLaterManager(this);
     connect(mManager, SIGNAL(needUpdateConfigDialogBox()), SIGNAL(needUpdateConfigDialogBox()));
@@ -61,9 +62,9 @@ SendLaterAgent::SendLaterAgent(const QString &id)
 
     if (SendLaterAgentSettings::enabled()) {
 #ifdef DEBUG_SENDLATERAGENT
-        QTimer::singleShot(1000, mManager, SLOT(load()));
+        QTimer::singleShot(1000, this, SLOT(slotStartAgent()));
 #else
-        QTimer::singleShot(1000*60*4, mManager, SLOT(load()));
+        QTimer::singleShot(1000*60*4, this, SLOT(slotStartAgent()));
 #endif
     }
 }
@@ -72,17 +73,27 @@ SendLaterAgent::~SendLaterAgent()
 {
 }
 
+void SendLaterAgent::slotStartAgent()
+{
+    mAgentInitialized = true;
+    if (isOnline())
+        mManager->load();
+}
+
 void SendLaterAgent::doSetOnline( bool online )
 {
-    if (online) {
-        reload();
-    } else {
-        mManager->stopAll();
+    if (mAgentInitialized) {
+        if (online) {
+            reload();
+        } else {
+            mManager->stopAll();
+        }
     }
 }
 
 void SendLaterAgent::reload()
 {
+    qDebug()<<" void SendLaterAgent::reload()";
     if (SendLaterAgentSettings::enabled())
         mManager->load(true);
 }
