@@ -38,11 +38,11 @@ SendLaterDialog::SendLaterDialog(SendLater::SendLaterInfo *info, QWidget *parent
     setCaption( i18nc("@title:window", "Send Later") );
     setWindowIcon( KIcon( QLatin1String("kmail") ) );
 
-    QWidget *sendLaterWidget = new QWidget;
+    QWidget *sendLaterWidget = new QWidget(this);
     mSendLaterWidget = new Ui::SendLaterWidget;
     mSendLaterWidget->setupUi( sendLaterWidget );
 
-    QWidget *w = new QWidget;
+    QWidget *w = new QWidget(this);
     QVBoxLayout *lay = new QVBoxLayout;
     w->setLayout(lay);
 
@@ -72,6 +72,7 @@ SendLaterDialog::SendLaterDialog(SendLater::SendLaterInfo *info, QWidget *parent
     unitsList<<i18n("Months");
     unitsList<<i18n("Years");
     mSendLaterWidget->mRecurrenceComboBox->addItems(unitsList);
+    connect(mSendLaterWidget->mDateTime, SIGNAL(dateChanged(QString)), this, SLOT(slotDateChanged(QString)));
 
     lay->addWidget(new KSeparator);
 
@@ -87,6 +88,11 @@ SendLaterDialog::~SendLaterDialog()
     delete mSendLaterWidget;
 }
 
+void SendLaterDialog::slotDateChanged(const QString &date)
+{
+    enableButtonOk(!date.isEmpty());
+}
+
 void SendLaterDialog::slotRecurrenceClicked(bool clicked)
 {
     mSendLaterWidget->mRecurrenceValue->setEnabled(clicked);
