@@ -35,8 +35,8 @@ Constants.
 
 static const char VERSION[] = "1.1";
 static const char APPNAME[] = "Blogilo";
-#define DATA_DIR KStandardDirs::locateLocal("data", "blogilo/")
-#define CONF_DB QString(DATA_DIR)+QString("/blogilo.db")
+#define DATA_DIR KStandardDirs::locateLocal("data", QLatin1String("blogilo/"))
+#define CONF_DB DATA_DIR+QLatin1String("/blogilo.db")
 static const int STATUSTIMEOUT = 5000;
 
 
