@@ -28,7 +28,7 @@ public:
     explicit ThemeTemplateListWidget(const QString &configName, QWidget *parent = 0);
     ~ThemeTemplateListWidget();
 
-    QVector<PimCommon::defaultTemplate> defaultTemplates();
+    QList<PimCommon::defaultTemplate> defaultTemplates();
 };
 
 class ThemeTemplateWidget : public QWidget
