@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -25,6 +25,7 @@ class GRANTLEETHEME_EXPORT Theme
 {
 public:
     Theme();
+    Theme(const QString &themePath, const QString &dirName, const QString &defaultDesktopFileName);
     ~Theme();
 
     bool isValid() const;
@@ -32,8 +33,8 @@ public:
     QString description() const;
     void setDescription(const QString &description);
 
-    QString filename() const;
-    void setFilename(const QString &file);
+    QString themeFilename() const;
+    void setThemeFilename(const QString &file);
 
     QString name() const;
     void setName(const QString &);
@@ -55,7 +56,7 @@ public:
 
 private:
     QStringList mDisplayExtraVariables;
-    QString mFileName;
+    QString mThemeFileName;
     QString mDescription;
     QString mName;
     QString mDirName;
