@@ -23,11 +23,11 @@
 #include "globalcontactmodel.h"
 #include "modelcolumnmanager.h"
 #include "printing/printingwizard.h"
-#include "merge/mergecontactsdialog.h"
-#include "merge/mergecontactduplicatecontactdialog.h"
+#include "merge/manualmerge/mergecontactsdialog.h"
+#include "merge/searchduplicate/searchandmergecontactduplicatecontactdialog.h"
 #include "quicksearchwidget.h"
 #include "settings.h"
-#include "xxportmanager.h"
+#include "xxport/xxportmanager.h"
 #include "utils.h"
 #include "kaddressbookadaptor.h"
 #include "categoryselectwidget.h"
@@ -287,7 +287,9 @@ MainWidget::MainWidget( KXMLGUIClient *guiClient, QWidget *parent )
                   << Akonadi::StandardActionManager::DeleteResources
                   << Akonadi::StandardActionManager::ResourceProperties
                   << Akonadi::StandardActionManager::SynchronizeResources
-                  << Akonadi::StandardActionManager::SynchronizeCollectionsRecursive;
+                  << Akonadi::StandardActionManager::SynchronizeCollectionsRecursive
+                  << Akonadi::StandardActionManager::MoveItemToMenu
+                  << Akonadi::StandardActionManager::CopyItemToMenu;
 
   Q_FOREACH( Akonadi::StandardActionManager::Type standardAction, standardActions ) {
     mActionManager->createAction( standardAction );
@@ -972,7 +974,8 @@ void MainWidget::slotGrantleeThemesUpdated()
 void MainWidget::mergeContacts()
 {
     const Akonadi::Item::List lst = Utils::collectSelectedContactsItem(mItemView->selectionModel());
-    QPointer<KABMergeContacts::MergeContactsDialog> dlg = new KABMergeContacts::MergeContactsDialog(lst, this);
+    QPointer<KABMergeContacts::MergeContactsDialog> dlg = new KABMergeContacts::MergeContactsDialog(this);
+    dlg->setContacts(lst);
     dlg->exec();
     delete dlg;
 }
@@ -980,7 +983,8 @@ void MainWidget::mergeContacts()
 void MainWidget::slotSearchDuplicateContacts()
 {
     const Akonadi::Item::List lst = Utils::collectSelectedContactsItem(mItemView->selectionModel());
-    QPointer<KABMergeContacts::MergeContactDuplicateContactDialog> dlg = new KABMergeContacts::MergeContactDuplicateContactDialog(lst, this);
+    QPointer<KABMergeContacts::SearchAndMergeContactDuplicateContactDialog> dlg = new KABMergeContacts::SearchAndMergeContactDuplicateContactDialog(this);
+    dlg->searchPotentialDuplicateContacts(lst);
     dlg->exec();
     delete dlg;
 }
