@@ -20,7 +20,6 @@
 
 #ifndef SENDVCARDSJOB_H
 #define SENDVCARDSJOB_H
-#include "kaddressbook_export.h"
 #include <QObject>
 #include <Akonadi/Item>
 #include <QStringList>
@@ -29,7 +28,7 @@ namespace PimCommon {
 class AttachmentTemporaryFilesDirs;
 }
 namespace KABSendVCards {
-class KADDRESSBOOK_EXPORT SendVcardsJob : public QObject
+class SendVcardsJob : public QObject
 {
     Q_OBJECT
 public:
