@@ -29,7 +29,7 @@ class CsvXXPort : public XXPort
 public:
     explicit CsvXXPort( QWidget *parent = 0 );
 
-    bool exportContacts( const KABC::Addressee::List &contacts ) const;
+    bool exportContacts( const KABC::Addressee::List &contacts, VCardExportSelectionWidget::ExportFields ) const;
     KABC::Addressee::List importContacts() const;
 
 private:
