@@ -33,7 +33,7 @@ class LDAPXXPort : public XXPort
 public:
     explicit LDAPXXPort( QWidget *parent = 0 );
     KABC::Addressee::List importContacts() const;
-    bool exportContacts( const KABC::Addressee::List &contacts ) const;
+    bool exportContacts(const KABC::Addressee::List &contacts , VCardExportSelectionWidget::ExportFields) const;
 };
 
 #endif
