@@ -32,7 +32,7 @@ class LDIFXXPort : public XXPort
 public:
     explicit LDIFXXPort( QWidget *parent = 0 );
 
-    bool exportContacts( const KABC::Addressee::List &contacts ) const;
+    bool exportContacts(const KABC::Addressee::List &contacts , VCardExportSelectionWidget::ExportFields) const;
     KABC::Addressee::List importContacts() const;
 };
 
