@@ -19,6 +19,9 @@
 
 #include "vcard_xxport.h"
 
+#include "vcardviewerdialog.h"
+#include "vcardexportselectionwidget.h"
+
 #include "pimcommon/widgets/renamefiledialog.h"
 
 #include <kaddressbookgrantlee/widget/grantleecontactviewer.h>
@@ -46,74 +49,19 @@
 
 #include <QtCore/QFile>
 #include <QtCore/QPointer>
-#include <QCheckBox>
-#include <QFont>
-#include <QFrame>
-#include <QLabel>
-#include <QPushButton>
-#include <QVBoxLayout>
-#include <QGroupBox>
 
-class VCardViewerDialog : public KDialog
-{
-    Q_OBJECT
-public:
-    VCardViewerDialog( const KABC::Addressee::List &list,
-                       QWidget *parent );
-    ~VCardViewerDialog();
-
-    KABC::Addressee::List contacts() const;
-
-protected Q_SLOTS:
-    void slotYes();
-    void slotNo();
-    void slotApply();
-    void slotCancel();
-
-private:
-    void readConfig();
-    void writeConfig();
-    void updateView();
-
-    KAddressBookGrantlee::GrantleeContactViewer *mView;
-
-    KABC::Addressee::List mContacts;
-    KABC::Addressee::List::Iterator mIt;
-};
-
-class VCardExportSelectionDialog : public KDialog
-{
-public:
-    VCardExportSelectionDialog( QWidget *parent );
-    ~VCardExportSelectionDialog();
-
-    bool exportPrivateFields() const;
-    bool exportBusinessFields() const;
-    bool exportOtherFields() const;
-    bool exportEncryptionKeys() const;
-    bool exportPictureFields() const;
-    bool exportDisplayName() const;
-
-private:
-    QCheckBox *mPrivateBox;
-    QCheckBox *mBusinessBox;
-    QCheckBox *mOtherBox;
-    QCheckBox *mEncryptionKeys;
-    QCheckBox *mPictureBox;
-    QCheckBox *mDisplayNameBox;
-};
 
 VCardXXPort::VCardXXPort( QWidget *parent )
     : XXPort( parent )
 {
 }
 
-bool VCardXXPort::exportContacts( const KABC::Addressee::List &contacts ) const
+bool VCardXXPort::exportContacts( const KABC::Addressee::List &contacts, VCardExportSelectionWidget::ExportFields exportFields) const
 {
     KABC::VCardConverter converter;
     KUrl url;
 
-    const KABC::Addressee::List list = filterContacts( contacts );
+    const KABC::Addressee::List list = filterContacts( contacts, exportFields );
     if ( list.isEmpty() ) { // no contact selected
         return true;
     }
@@ -320,7 +268,7 @@ bool VCardXXPort::doExport( const KUrl &url, const QByteArray &data ) const
     return KIO::NetAccess::upload( tmpFile.fileName(), newUrl, parentWidget() );
 }
 
-KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &addrList ) const
+KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &addrList, VCardExportSelectionWidget::ExportFields exportFieldType ) const
 {
     KABC::Addressee::List list;
 
@@ -328,12 +276,6 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
         return addrList;
     }
 
-    QPointer<VCardExportSelectionDialog> dlg = new VCardExportSelectionDialog( parentWidget() );
-    if ( !dlg->exec() || !dlg ) {
-        delete dlg;
-        return list;
-    }
-
     KABC::Addressee::List::ConstIterator it;
     KABC::Addressee::List::ConstIterator end( addrList.end() );
     for ( it = addrList.begin(); it != end; ++it ) {
@@ -343,7 +285,7 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
         addr.setFormattedName( (*it).formattedName() );
 
         bool addrDone = false;
-        if ( dlg->exportDisplayName() ) {                // output display name as N field
+        if ( exportFieldType & VCardExportSelectionWidget::DiplayName ) {                // output display name as N field
             QString fmtName = (*it).formattedName();
             QStringList splitNames = fmtName.split( QLatin1Char(' '), QString::SkipEmptyParts );
             if ( splitNames.count() >= 2 ) {
@@ -371,27 +313,37 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
         addr.setProductId( (*it).productId() );
         addr.setSortString( (*it).sortString() );
         addr.setUrl( (*it).url() );
+        addr.setExtraUrlList( (*it).extraUrlList() );
         addr.setSecrecy( (*it).secrecy() );
         addr.setSound( (*it).sound() );
-        addr.setEmails( (*it).emails() );
+        addr.setEmailList( (*it).emailList() );
         addr.setCategories( (*it).categories() );
+        addr.setExtraSoundList( (*it).extraSoundList() );
+        addr.setGender( (*it).gender() );
+        addr.setLangs( (*it).langs() );
+        addr.setKind( (*it).kind() );
+        addr.setMembers( (*it).members() );
+        addr.setRelationShips( (*it).relationShips() );
+        addr.setSourcesUrlList( (*it).sourcesUrlList() );
 
-        if ( dlg->exportPrivateFields() ) {
+        if ( exportFieldType & VCardExportSelectionWidget::Private ) {
             addr.setBirthday( (*it).birthday() );
             addr.setNote( (*it).note() );
         }
 
-        if ( dlg->exportPictureFields() ) {
-            if ( dlg->exportPrivateFields() ) {
+        if ( exportFieldType & VCardExportSelectionWidget::Picture ) {
+            if ( exportFieldType & VCardExportSelectionWidget::Private ) {
                 addr.setPhoto( (*it).photo() );
+                addr.setExtraPhotoList( (*it).extraPhotoList() );
             }
 
-            if ( dlg->exportBusinessFields() ) {
+            if ( exportFieldType & VCardExportSelectionWidget::Business ) {
                 addr.setLogo( (*it).logo() );
+                addr.setExtraLogoList( (*it).extraLogoList() );
             }
         }
 
-        if ( dlg->exportBusinessFields() ) {
+        if ( exportFieldType & VCardExportSelectionWidget::Business ) {
             addr.setTitle( (*it).title() );
             addr.setRole( (*it).role() );
             addr.setOrganization( (*it).organization() );
@@ -413,13 +365,13 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
         KABC::PhoneNumber::List phones = (*it).phoneNumbers();
         KABC::PhoneNumber::List::Iterator phoneIt;
         for ( phoneIt = phones.begin(); phoneIt != phones.end(); ++phoneIt ) {
-            int type = (*phoneIt).type();
+            int phoneType = (*phoneIt).type();
 
-            if ( type & KABC::PhoneNumber::Home && dlg->exportPrivateFields() ) {
+            if ( (phoneType & KABC::PhoneNumber::Home) && (exportFieldType & VCardExportSelectionWidget::Private) ) {
                 addr.insertPhoneNumber( *phoneIt );
-            } else if ( type & KABC::PhoneNumber::Work && dlg->exportBusinessFields() ) {
+            } else if ( (phoneType & KABC::PhoneNumber::Work) && (exportFieldType & VCardExportSelectionWidget::Business) ) {
                 addr.insertPhoneNumber( *phoneIt );
-            } else if ( dlg->exportOtherFields() ) {
+            } else if ( (exportFieldType & VCardExportSelectionWidget::Other) ) {
                 addr.insertPhoneNumber( *phoneIt );
             }
         }
@@ -427,22 +379,22 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
         KABC::Address::List addresses = (*it).addresses();
         KABC::Address::List::Iterator addrIt;
         for ( addrIt = addresses.begin(); addrIt != addresses.end(); ++addrIt ) {
-            int type = (*addrIt).type();
+            int addressType = (*addrIt).type();
 
-            if ( type & KABC::Address::Home && dlg->exportPrivateFields() ) {
+            if ( (addressType & KABC::Address::Home) && exportFieldType & VCardExportSelectionWidget::Private ) {
                 addr.insertAddress( *addrIt );
-            } else if ( type & KABC::Address::Work && dlg->exportBusinessFields() ) {
+            } else if ( (addressType & KABC::Address::Work) && (exportFieldType & VCardExportSelectionWidget::Business) ) {
                 addr.insertAddress( *addrIt );
-            } else if ( dlg->exportOtherFields() ) {
+            } else if ( exportFieldType & VCardExportSelectionWidget::Other ) {
                 addr.insertAddress( *addrIt );
             }
         }
 
-        if ( dlg->exportOtherFields() ) {
+        if ( exportFieldType & VCardExportSelectionWidget::Other ) {
             addr.setCustoms( (*it).customs() );
         }
 
-        if ( dlg->exportEncryptionKeys() ) {
+        if ( exportFieldType & VCardExportSelectionWidget::Encryption ) {
             addKey( addr, KABC::Key::PGP );
             addKey( addr, KABC::Key::X509 );
         }
@@ -450,8 +402,6 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
         list.append( addr );
     }
 
-    delete dlg;
-
     return list;
 }
 
@@ -492,260 +442,3 @@ void VCardXXPort::addKey( KABC::Addressee &addr, KABC::Key::Type type ) const
     return;
 #endif
 }
-
-// ---------- VCardViewer Dialog ---------------- //
-
-VCardViewerDialog::VCardViewerDialog( const KABC::Addressee::List &list, QWidget *parent )
-    : KDialog( parent ),
-      mContacts( list )
-{
-    setCaption( i18nc( "@title:window", "Import vCard" ) );
-    setButtons( User1 | User2 | Apply | Cancel );
-    setButtonGuiItem(User1, KStandardGuiItem::no());
-    setButtonGuiItem(User2, KStandardGuiItem::yes());
-    setDefaultButton( User1 );
-    setModal( true );
-    showButtonSeparator( true );
-
-    QFrame *page = new QFrame( this );
-    setMainWidget( page );
-
-    QVBoxLayout *layout = new QVBoxLayout( page );
-    layout->setSpacing( spacingHint() );
-    layout->setMargin( marginHint() );
-
-    QLabel *label =
-            new QLabel(
-                i18nc( "@info", "Do you want to import this contact into your address book?" ), page );
-    QFont font = label->font();
-    font.setBold( true );
-    label->setFont( font );
-    layout->addWidget( label );
-
-    mView = new KAddressBookGrantlee::GrantleeContactViewer( page );
-
-    layout->addWidget( mView );
-
-    setButtonText( Apply, i18nc( "@action:button", "Import All..." ) );
-
-    mIt = mContacts.begin();
-
-    connect( this, SIGNAL(user2Clicked()), this, SLOT(slotYes()) );
-    connect( this, SIGNAL(user1Clicked()), this, SLOT(slotNo()) );
-    connect( this, SIGNAL(applyClicked()), this, SLOT(slotApply()) );
-    connect( this, SIGNAL(cancelClicked()), this, SLOT(slotCancel()) );
-
-    updateView();
-    readConfig();
-}
-
-VCardViewerDialog::~VCardViewerDialog()
-{
-    writeConfig();
-}
-
-void VCardViewerDialog::readConfig()
-{
-    KConfigGroup group( KGlobal::config(), "VCardViewerDialog" );
-    const QSize size = group.readEntry( "Size", QSize(600, 400) );
-    if ( size.isValid() ) {
-        resize( size );
-    }
-}
-
-void VCardViewerDialog::writeConfig()
-{
-    KConfigGroup group( KGlobal::config(), "VCardViewerDialog" );
-    group.writeEntry( "Size", size() );
-    group.sync();
-}
-
-
-KABC::Addressee::List VCardViewerDialog::contacts() const
-{
-    return mContacts;
-}
-
-void VCardViewerDialog::updateView()
-{
-    mView->setRawContact( *mIt );
-
-    KABC::Addressee::List::Iterator it = mIt;
-    enableButton( Apply, ( ++it ) != mContacts.end() );
-}
-
-void VCardViewerDialog::slotYes()
-{
-    mIt++;
-
-    if ( mIt == mContacts.end() ) {
-        slotApply();
-        return;
-    }
-
-    updateView();
-}
-
-void VCardViewerDialog::slotNo()
-{
-    if ( mIt == mContacts.end() ) {
-        accept();
-        return;
-    }
-    // remove the current contact from the result set
-    mIt = mContacts.erase( mIt );
-    if ( mIt == mContacts.end() ) {
-        return;
-    }
-
-    updateView();
-}
-
-void VCardViewerDialog::slotApply()
-{
-    KDialog::accept();
-}
-
-void VCardViewerDialog::slotCancel()
-{
-    mContacts.clear();
-    reject();
-}
-
-// ---------- VCardExportSelection Dialog ---------------- //
-
-VCardExportSelectionDialog::VCardExportSelectionDialog( QWidget *parent )
-    : KDialog( parent )
-{
-    setCaption( i18nc( "@title:window", "Select vCard Fields" ) );
-    setButtons( Ok | Cancel );
-    setDefaultButton( Ok );
-    setModal( true );
-    showButtonSeparator( true );
-
-    QFrame *page = new QFrame( this );
-    setMainWidget( page );
-
-    QGridLayout *layout = new QGridLayout( page );
-    layout->setSpacing( spacingHint() );
-    layout->setMargin( marginHint() );
-
-    QGroupBox *gbox = new QGroupBox(
-                i18nc( "@title:group", "Fields to be exported" ), page );
-    gbox->setFlat( true );
-    layout->addWidget( gbox, 0, 0, 1, 2 );
-
-    mPrivateBox = new QCheckBox( i18nc( "@option:check", "Private fields" ), page );
-    mPrivateBox->setToolTip(
-                i18nc( "@info:tooltip", "Export private fields" ) );
-    mPrivateBox->setWhatsThis(
-                i18nc( "@info:whatsthis",
-                       "Check this box if you want to export the contact's "
-                       "private fields to the vCard output file." ) );
-    layout->addWidget( mPrivateBox, 1, 0 );
-
-    mBusinessBox = new QCheckBox( i18nc( "@option:check", "Business fields" ), page );
-    mBusinessBox->setToolTip(
-                i18nc( "@info:tooltip", "Export business fields" ) );
-    mBusinessBox->setWhatsThis(
-                i18nc( "@info:whatsthis",
-                       "Check this box if you want to export the contact's "
-                       "business fields to the vCard output file." ) );
-    layout->addWidget( mBusinessBox, 2, 0 );
-
-    mOtherBox = new QCheckBox( i18nc( "@option:check", "Other fields" ), page );
-    mOtherBox->setToolTip(
-                i18nc( "@info:tooltip", "Export other fields" ) );
-    mOtherBox->setWhatsThis(
-                i18nc( "@info:whatsthis",
-                       "Check this box if you want to export the contact's "
-                       "other fields to the vCard output file." ) );
-    layout->addWidget( mOtherBox, 3, 0 );
-
-    mEncryptionKeys = new QCheckBox( i18nc( "@option:check", "Encryption keys" ), page );
-    mEncryptionKeys->setToolTip(
-                i18nc( "@info:tooltip", "Export encryption keys" ) );
-    mEncryptionKeys->setWhatsThis(
-                i18nc( "@info:whatsthis",
-                       "Check this box if you want to export the contact's "
-                       "encryption keys to the vCard output file." ) );
-    layout->addWidget( mEncryptionKeys, 1, 1 );
-
-    mPictureBox = new QCheckBox( i18nc( "@option:check", "Pictures" ), page );
-    mPictureBox->setToolTip(
-                i18nc( "@info:tooltip", "Export pictures" ) );
-    mPictureBox->setWhatsThis(
-                i18nc( "@info:whatsthis",
-                       "Check this box if you want to export the contact's "
-                       "picture to the vCard output file." ) );
-    layout->addWidget( mPictureBox, 2, 1 );
-
-    gbox = new QGroupBox(
-                i18nc( "@title:group", "Export options" ), page );
-    gbox->setFlat( true );
-    layout->addWidget( gbox, 4, 0, 1, 2 );
-
-    mDisplayNameBox = new QCheckBox( i18nc( "@option:check", "Display name as full name" ), page );
-    mDisplayNameBox->setToolTip(
-                i18nc( "@info:tooltip", "Export display name as full name" ) );
-    mDisplayNameBox->setWhatsThis(
-                i18nc( "@info:whatsthis",
-                       "Check this box if you want to export the contact's display name "
-                       "in the vCard's full name field.  This may be required to get the "
-                       "name shown correctly in GMail or Android." ) );
-    layout->addWidget( mDisplayNameBox, 5, 0, 1, 2 );
-
-    KConfig config( QLatin1String("kaddressbookrc") );
-    const KConfigGroup group( &config, "XXPortVCard" );
-
-    mPrivateBox->setChecked( group.readEntry( "ExportPrivateFields", true ) );
-    mBusinessBox->setChecked( group.readEntry( "ExportBusinessFields", true ) );
-    mOtherBox->setChecked( group.readEntry( "ExportOtherFields", true ) );
-    mEncryptionKeys->setChecked( group.readEntry( "ExportEncryptionKeys", true ) );
-    mPictureBox->setChecked( group.readEntry( "ExportPictureFields", true ) );
-    mDisplayNameBox->setChecked( group.readEntry( "ExportDisplayName", false ) );
-}
-
-VCardExportSelectionDialog::~VCardExportSelectionDialog()
-{
-    KConfig config( QLatin1String("kaddressbookrc") );
-    KConfigGroup group( &config, "XXPortVCard" );
-
-    group.writeEntry( "ExportPrivateFields", mPrivateBox->isChecked() );
-    group.writeEntry( "ExportBusinessFields", mBusinessBox->isChecked() );
-    group.writeEntry( "ExportOtherFields", mOtherBox->isChecked() );
-    group.writeEntry( "ExportEncryptionKeys", mEncryptionKeys->isChecked() );
-    group.writeEntry( "ExportPictureFields", mPictureBox->isChecked() );
-    group.writeEntry( "ExportDisplayName", mDisplayNameBox->isChecked() );
-}
-
-bool VCardExportSelectionDialog::exportPrivateFields() const
-{
-    return mPrivateBox->isChecked();
-}
-
-bool VCardExportSelectionDialog::exportBusinessFields() const
-{
-    return mBusinessBox->isChecked();
-}
-
-bool VCardExportSelectionDialog::exportOtherFields() const
-{
-    return mOtherBox->isChecked();
-}
-
-bool VCardExportSelectionDialog::exportEncryptionKeys() const
-{
-    return mEncryptionKeys->isChecked();
-}
-
-bool VCardExportSelectionDialog::exportPictureFields() const
-{
-    return mPictureBox->isChecked();
-}
-
-bool VCardExportSelectionDialog::exportDisplayName() const
-{
-    return mDisplayNameBox->isChecked();
-}
-#include "vcard_xxport.moc"
