@@ -90,10 +90,11 @@ void PotentialPhishingDetailDialog::slotSave()
     KConfigGroup group( KGlobal::config(), "PotentialPhishing");
     QStringList potentialPhishing = group.readEntry("whiteList", QStringList());
     bool emailsAdded = false;
-    for (int i=0; i < mListWidget->count(); ++i) {
+    const int numberOfItem(mListWidget->count());
+    for (int i=0; i < numberOfItem; ++i) {
         QListWidgetItem *item = mListWidget->item(i);
         if (item->checkState() == Qt::Checked) {
-            QString email = item->text();
+            const QString email = item->text();
             if (!potentialPhishing.contains(email)) {
                 potentialPhishing << email;
                 emailsAdded = true;
