@@ -22,7 +22,7 @@
 #define POTENTIALPHISHINGDETAILDIALOG_H
 
 #include <KDialog>
-class PotentialPhishingDetailWidget;
+class QListWidget;
 class PotentialPhishingDetailDialog : public KDialog
 {
     Q_OBJECT
@@ -38,7 +38,7 @@ private slots:
 private:
     void readConfig();
     void writeConfig();
-    PotentialPhishingDetailWidget *mPotentialPhishingDetailWidget;
+    QListWidget *mListWidget;
 };
 
 #endif // POTENTIALPHISHINGDETAILDIALOG_H
