@@ -1,7 +1,7 @@
 /* -*- mode: C++; c-file-style: "gnu" -*-
     This file is part of KMail, the KDE mail client.
     Copyright (c) 2002 Don Sanders <sanders@kde.org>
-    Copyright (c) 2013 Laurent Montel <montel@kde.org>
+    Copyright (C) 2013-2015 Laurent Montel <montel@kde.org>
 
     KMail is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License, version 2, as
@@ -74,7 +74,7 @@
 
 #include "messagecore/misc/mailinglist.h"
 #include "editor/composer.h"
-#include "mailcommon/filter/filteraction.h"
+#include "mailcommon/filter/filteractions/filteraction.h"
 #include "mailcommon/filter/filtermanager.h"
 #include "mailcommon/filter/mailfilter.h"
 #include "mailcommon/widgets/redirectdialog.h"
@@ -272,6 +272,11 @@ void KMCommand::slotPostTransfer( KMCommand::Result result )
         deleteLater();
 }
 
+Akonadi::ItemFetchJob *KMCommand::createFetchJob( const Akonadi::Item::List &items )
+{
+    return new Akonadi::ItemFetchJob( items, this );
+}
+
 void KMCommand::transferSelectedMsgs()
 {
     // make sure no other transfer is active
@@ -303,7 +308,7 @@ void KMCommand::transferSelectedMsgs()
     if ( !mFetchScope.isEmpty() ) {
         complete = false;
         ++KMCommand::mCountJobs;
-        Akonadi::ItemFetchJob *fetch = new Akonadi::ItemFetchJob( mMsgList, this );
+        Akonadi::ItemFetchJob *fetch = createFetchJob( mMsgList );
         mFetchScope.fetchAttribute< MessageCore::MDNStateAttribute >();
         fetch->setFetchScope( mFetchScope );
         connect( fetch, SIGNAL(itemsReceived(Akonadi::Item::List)), SLOT(slotMsgTransfered(Akonadi::Item::List)) );
@@ -687,6 +692,7 @@ KMOpenMsgCommand::KMOpenMsgCommand( QWidget *parent, const KUrl & url,
       mEncoding( encoding ),
       mMainWidget( main )
 {
+    qDebug()<<"url :"<<url;
 }
 
 KMCommand::Result KMOpenMsgCommand::execute()
@@ -747,6 +753,11 @@ void KMOpenMsgCommand::slotResult( KJob *job )
         emit completed( this );
     }
     else {
+        if (mMsgString.isEmpty()) {
+            qDebug()<<" Message not found. There is a problem";
+            doesNotContainMessage();
+            return;
+        }
         int startOfMessage = 0;
         if ( mMsgString.startsWith( QLatin1String( "From " ) ) ) {
             startOfMessage = mMsgString.indexOf( QLatin1Char('\n') );
@@ -1614,3 +1625,33 @@ KMCommand::Result KMShareImageCommand::execute()
     return OK;
 }
 
+KMFetchMessageCommand::KMFetchMessageCommand( QWidget *parent, const Akonadi::Item &item )
+    : KMCommand( parent, item )
+{
+    // Workaround KMCommand::transferSelectedMsgs() expecting non-empty fetchscope
+    fetchScope().fetchFullPayload(true);
+}
+
+Akonadi::ItemFetchJob *KMFetchMessageCommand::createFetchJob( const Akonadi::Item::List &items )
+{
+    Q_ASSERT( items.size() == 1 );
+    Akonadi::ItemFetchJob *fetch = MessageViewer::Viewer::createFetchJob( items.first() );
+    fetchScope() = fetch->fetchScope();
+    return fetch;
+}
+
+KMCommand::Result KMFetchMessageCommand::execute()
+{
+    Akonadi::Item item = retrievedMessage();
+    if ( !item.isValid() || !item.hasPayload<KMime::Message::Ptr>() ) {
+        return Failed;
+    }
+
+    mItem = item;
+    return OK;
+}
+
+Akonadi::Item KMFetchMessageCommand::item() const
+{
+    return mItem;
+}
