@@ -285,6 +285,8 @@ public Q_SLOTS:
 
     Q_SCRIPTABLE void showFolder(const QString &collectionId);
 
+    Q_SCRIPTABLE void reloadFolderArchiveConfig();
+
     /**
  * End of D-Bus callable stuff
  */
@@ -314,7 +316,6 @@ public:
 
     void init();
     void setupDBus();
-    void readConfig();
 
     /*reimp*/ Akonadi::ChangeRecorder *folderCollectionMonitor() const;
 
@@ -363,14 +364,8 @@ public:
     /** Expire all folders, used for the gui action */
     void expireAllFoldersNow();
 
-    int wrapCol() const { return mWrapCol;}
-
     bool firstStart() const { return the_firstStart; }
-    /** Mark first start as done */
-    void firstStartDone() { the_firstStart = false; }
     QString previousVersion() const { return the_previousVersion; }
-    bool startingUp() const { return the_startingUp; }
-    void setStartingUp (bool flag) { the_startingUp = flag; }
     bool shuttingDown() const { return the_shuttingDown; }
     void setShuttingDown(bool flag) { the_shuttingDown = flag; }
 
@@ -432,6 +427,8 @@ public:
     FolderArchiveManager *folderArchiveManager() const;
     PimCommon::StorageServiceManager *storageServiceManager() const;
 
+    bool allowToDebugBalooSupport() const;
+
 protected:
     void agentInstanceBroken( const Akonadi::AgentInstance& instance );
 
@@ -505,8 +502,6 @@ private:
     QString the_previousVersion;
     /** is this the first start?  read from config */
     bool the_firstStart;
-    /** are we starting up? set in main.cpp directly before kapp->exec() */
-    bool the_startingUp;
     /** are we going down? set from here */
     bool the_shuttingDown;
     /** true unles kmail is closed by session management */
@@ -534,12 +529,11 @@ private:
     /// List of Akonadi resources that are currently being checked.
     QList<QString> mResourcesBeingChecked;
 
-    int mWrapCol;
-
     QPointer<MailCommon::KMFilterDialog> mFilterEditDialog;
     PimCommon::AutoCorrection *mAutoCorrection;
     FolderArchiveManager *mFolderArchiveManager;
     PimCommon::StorageServiceManager *mStorageManager;
+    bool mDebugBaloo;
 };
 
 #endif // _KMKERNEL_H
