@@ -62,6 +62,8 @@
 #include <akonadi/item.h>
 #include <akonadi/itemcopyjob.h>
 #include <akonadi/itemcreatejob.h>
+#include <akonadi/itemmovejob.h>
+#include <akonadi/kmime/messageflags.h>
 
 #include "messagecore/helpers/messagehelpers.h"
 #include <util/mailutil.h>
@@ -167,6 +169,7 @@ void KMReaderMainWin::showMessage( const QString& encoding, KMime::Message::Ptr
     Akonadi::Item item;
 
     item.setPayload<KMime::Message::Ptr>( message );
+    Akonadi::MessageFlags::copyMessageFlags(*message, item);
     item.setMimeType( KMime::Message::mimeType() );
 
     mMsg = item;
@@ -371,14 +374,48 @@ KAction *KMReaderMainWin::copyActionMenu(QMenu *menu)
     {
         KActionMenu *action = new KActionMenu( menu );
         action->setIcon( KIcon( QLatin1String("edit-copy")) );
-        action->setText( i18n("Copy Item To...") );
+        action->setText(i18n("Copy Message To...") );
         mainwin->standardMailActionManager()->standardActionManager()->createActionFolderMenu( action->menu(), Akonadi::StandardActionManager::CopyItemToMenu );
         connect( action->menu(), SIGNAL(triggered(QAction*)), SLOT(slotCopyItem(QAction*)) );
 
         return action;
     }
     return 0;
+}
 
+KAction *KMReaderMainWin::moveActionMenu(QMenu *menu)
+{
+    KMMainWidget* mainwin = kmkernel->getKMMainWidget();
+    if ( mainwin )
+    {
+        KActionMenu *action = new KActionMenu( menu );
+        action->setText(i18n("Move Message To...") );
+        mainwin->standardMailActionManager()->standardActionManager()->createActionFolderMenu( action->menu(), Akonadi::StandardActionManager::MoveItemToMenu );
+        connect( action->menu(), SIGNAL(triggered(QAction*)), SLOT(slotMoveItem(QAction*)) );
+
+        return action;
+    }
+    return 0;
+
+}
+
+void KMReaderMainWin::slotMoveItem(QAction *action)
+{
+    if ( action )
+    {
+        const QModelIndex index = action->data().value<QModelIndex>();
+        const Akonadi::Collection collection = index.data( Akonadi::EntityTreeModel::CollectionRole ).value<Akonadi::Collection>();
+
+        if ( mMsg.isValid() ) {
+            Akonadi::ItemMoveJob *job = new Akonadi::ItemMoveJob( mMsg, collection,this );
+            connect( job, SIGNAL(result(KJob*)), this, SLOT(slotCopyMoveResult(KJob*)) );
+        }
+        else
+        {
+            Akonadi::ItemCreateJob *job = new Akonadi::ItemCreateJob( mMsg, collection, this );
+            connect( job, SIGNAL(result(KJob*)), this, SLOT(slotCopyMoveResult(KJob*)) );
+        }
+    }
 }
 
 void KMReaderMainWin::slotCopyItem(QAction*action)
@@ -390,17 +427,17 @@ void KMReaderMainWin::slotCopyItem(QAction*action)
 
         if ( mMsg.isValid() ) {
             Akonadi::ItemCopyJob *job = new Akonadi::ItemCopyJob( mMsg, collection,this );
-            connect( job, SIGNAL(result(KJob*)), this, SLOT(slotCopyResult(KJob*)) );
+            connect( job, SIGNAL(result(KJob*)), this, SLOT(slotCopyMoveResult(KJob*)) );
         }
         else
         {
             Akonadi::ItemCreateJob *job = new Akonadi::ItemCreateJob( mMsg, collection, this );
-            connect( job, SIGNAL(result(KJob*)), this, SLOT(slotCopyResult(KJob*)) );
+            connect( job, SIGNAL(result(KJob*)), this, SLOT(slotCopyMoveResult(KJob*)) );
         }
     }
 }
 
-void KMReaderMainWin::slotCopyResult( KJob * job )
+void KMReaderMainWin::slotCopyMoveResult( KJob * job )
 {
     if ( job->error() ) {
         KMessageBox::sorry( this, i18n("Cannot copy item. %1", job->errorString() ) );
@@ -551,6 +588,7 @@ void KMReaderMainWin::showMessagePopup(const Akonadi::Item&msg ,const KUrl&url,c
                 menu->addSeparator();
             }
             menu->addAction( copyActionMenu(menu) );
+            menu->addAction( moveActionMenu(menu));
 
             menu->addSeparator();
             if(!imageUrl.isEmpty()) {
