@@ -75,13 +75,15 @@ private slots:
     /// forwarding is set.
     void slotReplyOrForwardFinished();
     void slotCopyItem(QAction*);
-    void slotCopyResult( KJob * job );
+    void slotCopyMoveResult( KJob * job );
+    void slotMoveItem(QAction *action);
 
 private:
     Akonadi::Collection parentCollection() const;
     void initKMReaderMainWin();
     void setupAccel();
     KAction *copyActionMenu(QMenu *menu);
+    KAction *moveActionMenu(QMenu *menu);
 
     KMReaderWin *mReaderWin;
     Akonadi::Item mMsg;
