@@ -21,7 +21,22 @@
 #include "pimcommon/widgets/simplestringlisteditor.h"
 #include <KDialog>
 
+class KUrlRequester;
 namespace MailMerge {
+class SelectAttachmentDialog : public KDialog
+{
+    Q_OBJECT
+public:
+    explicit SelectAttachmentDialog(QWidget *parent);
+    ~SelectAttachmentDialog();
+
+    void setAttachmentPath(const QString &path);
+    QString attachmentPath() const;
+
+private:
+    KUrlRequester *mUrlRequester;
+};
+
 class AttachmentListWidget : public PimCommon::SimpleStringListEditor
 {
     Q_OBJECT
