@@ -19,7 +19,6 @@
 
 #include "knotecollectionconfigwidget.h"
 #include "noteshared/attributes/showfoldernotesattribute.h"
-#include "noteshared/settings/globalsettings.h"
 #include "akonadi_next/note.h"
 #include "notesharedglobalconfig.h"
 #include "pimcommon/widgets/manageaccountwidget.h"
@@ -138,6 +137,13 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
     vbox->addWidget(new QLabel(i18nc( "@info", "Select the folder where the note will be saved:" )));
     mDefaultSaveFolder = new Akonadi::CollectionRequester(Akonadi::Collection(NoteShared::NoteSharedGlobalConfig::self()->defaultFolder()));
     mDefaultSaveFolder->setMimeTypeFilter(QStringList() << Akonotes::Note::mimeType());
+    mDefaultSaveFolder->setContentMimeTypes(QStringList() << QLatin1String("application/x-vnd.akonadi.note")
+                                            << QLatin1String("text/x-vnd.akonadi.note")
+                                            << QLatin1String("inode/directory"));
+    Akonadi::CollectionDialog::CollectionDialogOptions options;
+    options |= Akonadi::CollectionDialog::AllowToCreateNewChildCollection;
+    options |= Akonadi::CollectionDialog::KeepTreeExpanded;
+    mDefaultSaveFolder->changeCollectionDialogOptions(options);
     connect(mDefaultSaveFolder, SIGNAL(collectionChanged(Akonadi::Collection)), this, SLOT(slotDataChanged()));
 
     vbox->addWidget(mDefaultSaveFolder);
@@ -279,7 +285,7 @@ void KNoteCollectionConfigWidget::save()
     Akonadi::Collection col = mDefaultSaveFolder->collection();
     if (col.isValid()) {
         NoteShared::NoteSharedGlobalConfig::self()->setDefaultFolder(col.id());
-        NoteShared::GlobalSettings::self()->requestSync();
+        NoteShared::NoteSharedGlobalConfig::self()->writeConfig();
     }
 }
 
