@@ -271,7 +271,13 @@ QString KTNEFMain::extractTemp( KTNEFAttach *att )
 {
   QString dir = KGlobal::dirs()->localkdedir() + QLatin1String("/share/apps/ktnef/tmp/");
   mParser->extractFileTo( att->name(), dir );
-  dir.append( att->name() );
+  QString filename = att->fileName();
+  // falling back to internal TNEF attachement name if no filename is given for the attached file
+  // this follows the logic of KTNEFParser::extractFileTo(...)
+  if ( filename.isEmpty() ) {
+    filename = att->name();
+  }
+  dir.append( filename );
   return dir;
 }
 
@@ -349,8 +355,9 @@ void KTNEFMain::optionDefaultDir()
 void KTNEFMain::viewSelectionChanged()
 {
   const QList<KTNEFAttach *> list = mView->getSelection();
-  bool on1 = ( list.count() == 1 );
-  bool on2 = ( list.count() > 0 );
+  const int nbItem = list.count();
+  const bool on1 = ( nbItem == 1 );
+  const bool on2 = ( nbItem > 0 );
 
   actionCollection()->action( QLatin1String("view_file") )->setEnabled( on1 );
   actionCollection()->action( QLatin1String("view_file_as") )->setEnabled( on1 );
