@@ -82,6 +82,7 @@ public:
 
     void setEnableBalooSearch(bool enable);
 
+    bool isCompletionEnabled() const;
 Q_SIGNALS:
     void textCompleted();
 
@@ -175,6 +176,7 @@ protected:
     virtual void contextMenuEvent( QContextMenuEvent * );
 #endif
 
+    QStringList cleanupEmailList(const QStringList &inputList);
 private:
     virtual bool eventFilter( QObject *, QEvent * );
     void emitTextCompleted();
