@@ -24,6 +24,7 @@
 #include <QWidget>
 class KPushButton;
 class KLineEdit;
+class QLabel;
 namespace KPIM {
 class BlackListBalooEmailList;
 class BlackListBalooEmailCompletionWidget : public QWidget
@@ -36,16 +37,24 @@ public:
     void save();
     void setEmailBlackList(const QStringList &list);
 private slots:
+    void slotSelectionChanged();
     void slotUnselectEmails();
     void slotSelectEmails();
     void slotSearchLineEditChanged(const QString &text);
     void slotSearch();
+    void slotLinkClicked(const QString &link);
+    void slotEmailFound(const QStringList &list);
 private:
+    void hideMoreResultAndChangeLimit();
     void load();
     KLineEdit *mSearchLineEdit;
     KLineEdit *mExcludeDomainLineEdit;
     BlackListBalooEmailList *mEmailList;
     KPushButton *mSearchButton;
+    KPushButton *mSelectButton;
+    KPushButton *mUnselectButton;
+    QLabel *mMoreResult;
+    int mLimit;
 };
 }
 
