@@ -100,10 +100,12 @@ AddHostDialog::AddHostDialog( KLDAP::LdapServer *server, QWidget *parent )
     connect(mCfg, SIGNAL(hostNameChanged(QString)), this, SLOT(slotHostEditChanged(QString)));
     connect( this, SIGNAL(okClicked()), SLOT(slotOk()) );
     enableButtonOk(!mServer->host().isEmpty());
+    readConfig();
 }
 
 AddHostDialog::~AddHostDialog()
 {
+    writeConfig();
 }
 
 void AddHostDialog::slotHostEditChanged( const QString &text )
@@ -111,6 +113,23 @@ void AddHostDialog::slotHostEditChanged( const QString &text )
     enableButtonOk( !text.isEmpty() );
 }
 
+void AddHostDialog::readConfig()
+{
+    KConfigGroup group( KGlobal::config(), "AddHostDialog" );
+    const QSize size = group.readEntry( "Size", QSize(600, 400) );
+    if ( size.isValid() ) {
+        resize( size );
+    }
+}
+
+void AddHostDialog::writeConfig()
+{
+    KConfigGroup group( KGlobal::config(), "AddHostDialog" );
+    group.writeEntry( "Size", size() );
+    group.sync();
+}
+
+
 void AddHostDialog::slotOk()
 {
     mServer->setHost( mCfg->host() );
