@@ -21,8 +21,8 @@
 #include "autocreatescripts/autocreatescriptdialog.h"
 #include "editor/sieveinfowidget.h"
 #include "editor/sievetextedit.h"
-#include "editor/sieveeditorwarning.h"
-#include "editor/sieveeditorparsingmissingfeaturewarning.h"
+#include "editor/warningwidget/sieveeditorwarning.h"
+#include "editor/warningwidget/sieveeditorparsingmissingfeaturewarning.h"
 #include "editor/sieveeditortabwidget.h"
 
 #include "scriptsparsing/xmlprintingscriptbuilder.h"
@@ -69,14 +69,14 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     mTemplateSplitter = new QSplitter;
     mTemplateSplitter->setOrientation( Qt::Horizontal );
     //
-    SieveTemplateWidget *sieveTemplateWidget = new SieveTemplateWidget(i18n("Sieve Template:"));
+    mSieveTemplateWidget = new SieveTemplateWidget(i18n("Sieve Template:"));
 
     mSieveInfo = new SieveInfoWidget;
 
     mExtraSplitter = new QSplitter;
     mExtraSplitter->setOrientation( Qt::Vertical );
 
-    mExtraSplitter->addWidget(sieveTemplateWidget);
+    mExtraSplitter->addWidget(mSieveTemplateWidget);
     mExtraSplitter->addWidget(mSieveInfo);
     mExtraSplitter->setChildrenCollapsible(false);
 
@@ -121,7 +121,7 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     mTemplateSplitter->setCollapsible(0, false);
     new PimCommon::SplitterCollapser(mExtraSplitter, mTemplateSplitter);
 
-    connect(sieveTemplateWidget, SIGNAL(insertTemplate(QString)), mTextEdit, SLOT(insertPlainText(QString)));
+    connect(mSieveTemplateWidget, SIGNAL(insertTemplate(QString)), mTextEdit, SLOT(insertPlainText(QString)));
 
     //
     QShortcut *shortcut = new QShortcut( this );
@@ -141,7 +141,9 @@ SieveEditorTextModeWidget::SieveEditorTextModeWidget(QWidget *parent)
     mMainSplitter->addWidget( mDebugTextEdit );
     mMainSplitter->setChildrenCollapsible(false);
     connect( mTextEdit, SIGNAL(textChanged()), SLOT(slotTextChanged()) );
-
+    connect( mTextEdit, SIGNAL(undoAvailable(bool)), SIGNAL(undoAvailable(bool)));
+    connect( mTextEdit, SIGNAL(redoAvailable(bool)), SIGNAL(redoAvailable(bool)));
+    connect( mTextEdit, SIGNAL(copyAvailable(bool)), SIGNAL(copyAvailable(bool)));
     readConfig();
 
     mTextEdit->setFocus();
@@ -225,19 +227,75 @@ void SieveEditorTextModeWidget::autoGenerateScripts()
     delete dlg;
 }
 
+void SieveEditorTextModeWidget::find()
+{
+    slotFind();
+}
+
+void SieveEditorTextModeWidget::replace()
+{
+    slotReplace();
+}
+
+void SieveEditorTextModeWidget::undo()
+{
+    mTextEdit->undo();
+}
+
+void SieveEditorTextModeWidget::redo()
+{
+    mTextEdit->redo();
+}
+
+void SieveEditorTextModeWidget::paste()
+{
+    mTextEdit->paste();
+}
+
+void SieveEditorTextModeWidget::cut()
+{
+    mTextEdit->cut();
+}
+
+void SieveEditorTextModeWidget::copy()
+{
+    mTextEdit->copy();
+}
+
+void SieveEditorTextModeWidget::selectAll()
+{
+    mTextEdit->selectAll();
+}
+
+bool SieveEditorTextModeWidget::isUndoAvailable() const
+{
+    return mTextEdit->document()->isUndoAvailable();
+}
+
+bool SieveEditorTextModeWidget::isRedoAvailable() const
+{
+    return mTextEdit->document()->isRedoAvailable();
+}
+
+bool SieveEditorTextModeWidget::hasSelection() const
+{
+    return mTextEdit->textCursor().hasSelection();
+}
+
 void SieveEditorTextModeWidget::slotFind()
 {
-    mSliderContainer->slideIn();
     if ( mTextEdit->textCursor().hasSelection() )
         mFindBar->setText( mTextEdit->textCursor().selectedText() );
     mTextEdit->moveCursor(QTextCursor::Start);
     mFindBar->showFind();
+    mSliderContainer->slideIn();
     mFindBar->focusAndSetCursor();
 }
 
 void SieveEditorTextModeWidget::slotReplace()
 {
     mFindBar->showReplace();
+    mSliderContainer->slideIn();
     mFindBar->focusAndSetCursor();
 }
 
@@ -277,6 +335,7 @@ void SieveEditorTextModeWidget::setSieveCapabilities( const QStringList &capabil
 {
     mSieveCapabilities = capabilities;
     mTextEdit->setSieveCapabilities(mSieveCapabilities);
+    mSieveTemplateWidget->setSieveCapabilities(mSieveCapabilities);
     mSieveInfo->setServerInfo(capabilities);
 }
 
@@ -306,3 +365,7 @@ void SieveEditorTextModeWidget::goToLine()
     mGoToLine->goToLine();
 }
 
+void SieveEditorTextModeWidget::checkSpelling()
+{
+    mTextEdit->slotCheckSpelling();
+}
