@@ -37,6 +37,7 @@ class SieveTextEdit;
 class SieveEditorWarning;
 class SieveEditorParsingMissingFeatureWarning;
 class SieveEditorTabWidget;
+class SieveTemplateWidget;
 class SieveEditorTextModeWidget : public SieveEditorAbstractWidget
 {
     Q_OBJECT
@@ -65,10 +66,28 @@ public:
 
     void setParsingEditorWarningError(const QString &script, const QString &error);
     void goToLine();
+    void replace();
+    void find();
+    void undo();
+    void redo();    
+    void paste();
+    void cut();
+    void copy();
+    void checkSpelling();
+
+
+    bool isUndoAvailable() const;
+    bool isRedoAvailable() const;
+    bool hasSelection() const;
+
+    void selectAll();
 Q_SIGNALS:
     void enableButtonOk( bool );
     void switchToGraphicalMode();
     void valueChanged();
+    void undoAvailable(bool);
+    void redoAvailable(bool);
+    void copyAvailable(bool);
 
 private slots:
     void slotTextChanged();
@@ -94,6 +113,7 @@ private:
     SieveEditorTabWidget *mTabWidget;
     PimCommon::TextGoToLineWidget *mGoToLine;
     PimCommon::SlideContainer *mSliderContainer;
+    SieveTemplateWidget *mSieveTemplateWidget;
 };
 
 }
