@@ -25,6 +25,7 @@
 #include "scriptsparsing/parsingutil.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include "autocreatescripts/sievescriptparsingerrordialog.h"
+#include "sieveeditormenubar.h"
 
 #include <knewstuff3/uploaddialog.h>
 #include <klocale.h>
@@ -47,41 +48,76 @@
 
 using namespace KSieveUi;
 
-SieveEditorWidget::SieveEditorWidget(QWidget *parent)
+SieveEditorWidget::SieveEditorWidget(bool useMenuBar, QWidget *parent)
     : QWidget(parent),
       mMode(TextMode),
       mModified(false)
 {
     QVBoxLayout *lay = new QVBoxLayout;
+#if !defined(NDEBUG)
+    mGenerateXml = 0;
+#endif
+
+    QToolBar *toolbar = new QToolBar;
+    toolbar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
+
 
-    QToolBar *bar = new QToolBar;
-    bar->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     mCheckSyntax = new QAction(i18n("Check Syntax"), this);
     connect(mCheckSyntax, SIGNAL(triggered(bool)), SLOT(slotCheckSyntax()));
-    bar->addAction(mCheckSyntax);
-    mSaveAs = bar->addAction(KStandardGuiItem::saveAs().text(), this, SLOT(slotSaveAs()));
-    bar->addAction(i18n("Import..."), this, SLOT(slotImport()));
+    toolbar->addAction(mCheckSyntax);
+    mSaveAs = toolbar->addAction(KStandardGuiItem::saveAs().text(), this, SLOT(slotSaveAs()));
+    toolbar->addAction(i18n("Import..."), this, SLOT(slotImport()));
 
     mAutoGenerateScript = new QAction(i18n("Autogenerate Script..."), this);
     connect(mAutoGenerateScript, SIGNAL(triggered(bool)), SLOT(slotAutoGenerateScripts()));
-    bar->addAction(mAutoGenerateScript);
-    mSwitchMode = new QAction(i18n("Switch Mode"), this);
-    bar->addAction(mSwitchMode);
+    toolbar->addAction(mAutoGenerateScript);
+    //KF5 add i18n
+    mSwitchMode = new QAction(this);
+    toolbar->addAction(mSwitchMode);
     connect(mSwitchMode, SIGNAL(triggered(bool)), SLOT(slotSwitchMode()));
 #if !defined(NDEBUG)
-    //Not necessary to translate it.
-    mGenerateXml = new QAction(QLatin1String("Generate xml"), this);
-    connect(mGenerateXml, SIGNAL(triggered(bool)), SLOT(slotGenerateXml()));
-    bar->addAction(mGenerateXml);
+    if (!qgetenv("KDEPIM_SIEVEEDITOR_DEBUG").isEmpty()) {
+        //Not necessary to translate it.
+        mGenerateXml = new QAction(QLatin1String("Generate xml"), this);
+        connect(mGenerateXml, SIGNAL(triggered(bool)), SLOT(slotGenerateXml()));
+        toolbar->addAction(mGenerateXml);
+    }
 #endif
 
     QStringList overlays;
     overlays <<QLatin1String("list-add");
-    mUpload = new QAction(KIcon(QLatin1String("get-hot-new-stuff"), 0, overlays), i18n("Upload..."), this);
+    //KF5 add i18n + tooltip
+    mUpload = new QAction(KIcon(QLatin1String("get-hot-new-stuff"), 0, overlays), QLatin1String("Share..."), this);
     connect(mUpload, SIGNAL(triggered(bool)), SLOT(slotUploadScripts()));
-    bar->addAction(mUpload);
 
-    lay->addWidget(bar);
+    //Add action to toolBar
+
+    toolbar->addAction(mUpload);
+
+
+    SieveEditorMenuBar *menuBar = 0;
+    if (useMenuBar) {
+        menuBar = new SieveEditorMenuBar;
+        connect(menuBar, SIGNAL(copy()), SLOT(copy()));
+        connect(menuBar, SIGNAL(find()), SLOT(find()));
+        connect(menuBar, SIGNAL(replace()), SLOT(replace()));
+        connect(menuBar, SIGNAL(undo()), SLOT(undo()));
+        connect(menuBar, SIGNAL(redo()), SLOT(redo()));
+        connect(menuBar, SIGNAL(paste()), SLOT(paste()));
+        connect(menuBar, SIGNAL(cut()), SLOT(cut()));
+        connect(menuBar, SIGNAL(selectAll()), SLOT(selectAll()));
+        connect(menuBar, SIGNAL(gotoLine()), SLOT(goToLine()));
+        connect(this, SIGNAL(copyAvailable(bool)), menuBar, SLOT(slotCopyAvailable(bool)));
+        connect(this, SIGNAL(redoAvailable(bool)), menuBar, SLOT(slotRedoAvailable(bool)));
+        connect(this, SIGNAL(undoAvailable(bool)), menuBar, SLOT(slotUndoAvailable(bool)));
+        menuBar->fileMenu()->addAction(mSaveAs);
+        menuBar->fileMenu()->addSeparator();
+        menuBar->fileMenu()->addAction(mUpload);
+        menuBar->toolsMenu()->addAction(mAutoGenerateScript);
+        lay->addWidget(menuBar);
+    }
+
+    lay->addWidget(toolbar);
 
 
     QHBoxLayout *nameLayout = new QHBoxLayout;
@@ -106,11 +142,16 @@ SieveEditorWidget::SieveEditorWidget(QWidget *parent)
 
     lay->addWidget(mStackedWidget);
     connect(mTextModeWidget, SIGNAL(enableButtonOk(bool)), this, SLOT(slotEnableButtonOk(bool)));
+    connect(mTextModeWidget, SIGNAL(undoAvailable(bool)), this, SIGNAL(undoAvailable(bool)));
+    connect(mTextModeWidget, SIGNAL(redoAvailable(bool)), this, SIGNAL(redoAvailable(bool)));
+    connect(mTextModeWidget, SIGNAL(copyAvailable(bool)), this, SIGNAL(copyAvailable(bool)));
     connect(mGraphicalModeWidget, SIGNAL(enableButtonOk(bool)), this, SLOT(slotEnableButtonOk(bool)));
     connect(mGraphicalModeWidget, SIGNAL(switchTextMode(QString)), this, SLOT(slotSwitchTextMode(QString)));
     connect(mTextModeWidget, SIGNAL(switchToGraphicalMode()), SLOT(slotSwitchToGraphicalMode()));
     if (KSieveUi::EditorSettings::useGraphicEditorByDefault()) {
         changeMode(GraphicMode);
+    } else {
+        changeSwitchButtonText();
     }
 }
 
@@ -129,6 +170,20 @@ bool SieveEditorWidget::isModified() const
     return mModified;
 }
 
+void SieveEditorWidget::undo()
+{
+    if (mMode == TextMode) {
+        mTextModeWidget->undo();
+    }
+}
+
+void SieveEditorWidget::redo()
+{
+    if (mMode == TextMode) {
+        mTextModeWidget->redo();
+    }
+}
+
 void SieveEditorWidget::goToLine()
 {
     if (mMode == TextMode) {
@@ -136,6 +191,72 @@ void SieveEditorWidget::goToLine()
     }
 }
 
+void SieveEditorWidget::cut()
+{
+    if (mMode == TextMode) {
+        mTextModeWidget->cut();
+    }
+}
+
+void SieveEditorWidget::paste()
+{
+    if (mMode == TextMode) {
+        mTextModeWidget->paste();
+    }
+}
+
+void SieveEditorWidget::copy()
+{
+    if (mMode == TextMode) {
+        mTextModeWidget->copy();
+    }
+}
+
+void SieveEditorWidget::selectAll()
+{
+    if (mMode == TextMode) {
+        mTextModeWidget->selectAll();
+    }
+}
+
+void SieveEditorWidget::find()
+{
+    if (mMode == TextMode) {
+        mTextModeWidget->find();
+    }
+}
+
+void SieveEditorWidget::replace()
+{
+    if (mMode == TextMode) {
+        mTextModeWidget->replace();
+    }
+}
+
+bool SieveEditorWidget::isUndoAvailable() const
+{
+    if (mMode == TextMode) {
+        return mTextModeWidget->isUndoAvailable();
+    }
+    return false;
+}
+
+bool SieveEditorWidget::isRedoAvailable() const
+{
+    if (mMode == TextMode) {
+        return mTextModeWidget->isRedoAvailable();
+    }
+    return false;
+}
+
+bool SieveEditorWidget::hasSelection() const
+{
+    if (mMode == TextMode) {
+        return mTextModeWidget->hasSelection();
+    }
+    return false;
+}
+
 SieveEditorWidget::EditorMode SieveEditorWidget::mode() const
 {
     return mMode;
@@ -183,18 +304,27 @@ void SieveEditorWidget::changeMode(EditorMode mode)
     if (mode != mMode) {
         mMode = mode;
         mStackedWidget->setCurrentIndex(static_cast<int>(mode));
-        mAutoGenerateScript->setEnabled((mMode == TextMode));
+        const bool isTextMode = (mMode == TextMode);
+        mAutoGenerateScript->setEnabled(isTextMode);
 #if !defined(NDEBUG)
-        mGenerateXml->setEnabled((mMode == TextMode));
+        if (mGenerateXml)
+            mGenerateXml->setEnabled((mMode == TextMode));
 #endif
         if (mMode == GraphicMode)
             mCheckSyntax->setEnabled(false);
         else
             mCheckSyntax->setEnabled(!mTextModeWidget->currentscript().isEmpty());
         Q_EMIT modeEditorChanged(mode);
+        changeSwitchButtonText();
     }
 }
 
+void SieveEditorWidget::changeSwitchButtonText()
+{
+    //KF5 add i18n
+    mSwitchMode->setText((mMode == TextMode) ?  QLatin1String("Simple Mode") : QLatin1String("Advanced Mode"));
+}
+
 void SieveEditorWidget::slotEnableButtonOk(bool b)
 {
     Q_EMIT enableButtonOk(b);
@@ -314,6 +444,18 @@ void SieveEditorWidget::slotGenerateXml()
 #endif
 }
 
+void SieveEditorWidget::checkSpelling()
+{
+    switch (mMode) {
+    case TextMode:
+        mTextModeWidget->checkSpelling();
+        break;
+    case GraphicMode:
+    case Unknown:
+        break;
+    }
+}
+
 void SieveEditorWidget::slotSaveAs()
 {
     switch (mMode) {
