@@ -34,7 +34,7 @@ class KSIEVEUI_EXPORT SieveEditorWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorWidget(QWidget *parent=0);
+    explicit SieveEditorWidget(bool useMenuBar, QWidget *parent=0);
     ~SieveEditorWidget();
     enum EditorMode {
         Unknown = -1,
@@ -57,28 +57,49 @@ public:
 
     void setModified(bool b);
     bool isModified() const;
-    void goToLine();
+
     EditorMode mode() const;
 
+    bool isRedoAvailable() const;
+    bool isUndoAvailable() const;
+    bool hasSelection() const;
+
+    void checkSpelling();
+    void share();
+    void import();
+public Q_SLOTS:
+    void find();
+    void replace();
+    void undo();
+    void redo();
+    void paste();
+    void copy();
+    void cut();
+    void selectAll();
+    void goToLine();
+    void slotSaveAs();
+    void slotImport();
+    void slotUploadScripts();
+
 private Q_SLOTS:
     void slotEnableButtonOk(bool b);
     void slotAutoGenerateScripts();
     void slotCheckSyntax();
     void slotGenerateXml();
-    void slotSaveAs();
-    void slotImport();
     void slotSwitchMode();
     void slotSwitchTextMode(const QString &script);
     void slotSwitchToGraphicalMode();
-    void slotUploadScripts();
     void slotModified();
 Q_SIGNALS:
     void checkSyntax();
     void enableButtonOk(bool b);
     void valueChanged(bool b);
     void modeEditorChanged(KSieveUi::SieveEditorWidget::EditorMode);
-
+    void undoAvailable(bool);
+    void redoAvailable(bool);
+    void copyAvailable(bool);
 private:
+    void changeSwitchButtonText();
     void changeMode(EditorMode mode);
     void addMessageEntry(const QString &errorMsg, const QColor &color);
     QString mOriginalScript;
