@@ -92,11 +92,11 @@ SieveTemplateEditDialog::~SieveTemplateEditDialog()
 
 void SieveTemplateEditDialog::slotFind()
 {
-    mSliderContainer->slideIn();
     if ( mTextEdit->textCursor().hasSelection() )
         mFindBar->setText( mTextEdit->textCursor().selectedText() );
     mTextEdit->moveCursor(QTextCursor::Start);
     mFindBar->show();
+    mSliderContainer->slideIn();
     mFindBar->focusAndSetCursor();
 }
 
@@ -131,6 +131,11 @@ QString SieveTemplateEditDialog::script() const
     return mTextEdit->toPlainText();
 }
 
+void SieveTemplateEditDialog::setSieveCapabilities(const QStringList &capabilities)
+{
+    mTextEdit->setSieveCapabilities(capabilities);
+}
+
 void SieveTemplateEditDialog::setTemplateName(const QString &name)
 {
     mTemplateNameEdit->setText(name);
