@@ -38,6 +38,7 @@
 #include "filterimporter/filterimporterprocmail_p.h"
 #include "filterimporter/filterimporterbalsa_p.h"
 #include "filterimporter/filterimporterclawsmail_p.h"
+
 #include "dialog/selectthunderbirdfilterfilesdialog.h"
 
 #include <messageviewer/utils/autoqpointer.h>
@@ -175,7 +176,7 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
                 break;
             case ThunderBirdFilter:
                 title = i18n( "Import Thunderbird Filters" );
-                defaultPath = MailCommon::FilterImporterThunderbird::defaultFiltersSettingsPath();
+                defaultPath = MailCommon::FilterImporterThunderbird::defaultThunderbirdFiltersSettingsPath();
                 break;
             case EvolutionFilter:
                 title = i18n( "Import Evolution Filters" );
@@ -197,6 +198,10 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
                 title = i18n( "Import Claws Mail Filters" );
                 defaultPath = MailCommon::FilterImporterClawsMails::defaultFiltersSettingsPath();
                 break;
+            case IcedoveFilter:
+                title = i18n( "Import Icedove Filters" );
+                defaultPath = MailCommon::FilterImporterThunderbird::defaultIcedoveFiltersSettingsPath();
+                break;
             }
 
             fileName = KFileDialog::getOpenFileName(
@@ -226,11 +231,14 @@ QList<MailFilter *> FilterImporterExporter::importFilters(
         imported = readFiltersFromConfig( config, emptyFilter );
         break;
     }
+    case IcedoveFilter:
     case ThunderBirdFilter:
     {
         if (fileName.isEmpty()) {
-            SelectThunderbirdFilterFilesDialog * selectThunderBirdFileDialog = new SelectThunderbirdFilterFilesDialog(d->mParent);
-            selectThunderBirdFileDialog->setStartDir(KUrl(MailCommon::FilterImporterThunderbird::defaultFiltersSettingsPath()));
+            const QString defaultPath = ( type == ThunderBirdFilter ) ? MailCommon::FilterImporterThunderbird::defaultThunderbirdFiltersSettingsPath() : MailCommon::FilterImporterThunderbird::defaultIcedoveFiltersSettingsPath();
+
+            SelectThunderbirdFilterFilesDialog * selectThunderBirdFileDialog = new SelectThunderbirdFilterFilesDialog(defaultPath, d->mParent);
+            selectThunderBirdFileDialog->setStartDir(KUrl(defaultPath));
             if (selectThunderBirdFileDialog->exec()) {
                 Q_FOREACH(const QString& url, selectThunderBirdFileDialog->selectedFiles()) {
                     QFile fileThunderbird(url);
