@@ -55,6 +55,7 @@
 #include "mailimporter/filter_sylpheed.h"
 #include "mailimporter/filter_thunderbird.h"
 #include "mailimporter/filter_opera.h"
+#include "mailimporter/filtericedove.h"
 #include "mailimporter/othermailerutil.h"
 
 #include <incidenceeditor-ng/globalsettings.h>
@@ -444,6 +445,7 @@ bool MailCommon::Util::foundMailer()
     lst << MailImporter::FilterSylpheed::defaultSettingsPath();
     lst << MailImporter::FilterThunderbird::defaultSettingsPath();
     lst << MailImporter::OtherMailerUtil::trojitaDefaultPath();
+    lst << MailImporter::FilterIcedove::defaultSettingsPath();
 
     Q_FOREACH(const QString& path, lst) {
         QDir directory( path );
