@@ -22,7 +22,8 @@
 
 #include "composerlineedit.h"
 
-#include "addressline/recentaddresses.h"
+#include "addressline/recentaddress/recentaddresses.h"
+#include "addressline/recentaddress/recentaddressdialog.h"
 #include "settings/messagecomposersettings.h"
 #include "messageviewer/utils/autoqpointer.h"
 
@@ -204,9 +205,11 @@ void ComposerLineEdit::contextMenuEvent( QContextMenuEvent*e )
 {
     QPointer<QMenu> popup = createStandardContextMenu();
     if ( popup ) { // can be 0 on platforms with only a touch interface
-        popup->addSeparator();
-        QAction* act = popup->addAction( i18n( "Edit Recent Addresses..." ));
-        connect(act,SIGNAL(triggered(bool)), SLOT(editRecentAddresses()) );
+        if (isCompletionEnabled()) {
+            popup->addSeparator();
+            QAction* act = popup->addAction( i18n( "Edit Recent Addresses..." ));
+            connect(act,SIGNAL(triggered(bool)), SLOT(editRecentAddresses()) );
+        }
         popup->exec( e->globalPos() );
         delete popup;
     }
@@ -218,9 +221,11 @@ void ComposerLineEdit::editRecentAddresses()
     MessageViewer::AutoQPointer<KPIM::RecentAddressDialog> dlg( new KPIM::RecentAddressDialog( this ) );
     dlg->setAddresses( KPIM::RecentAddresses::self( m_recentAddressConfig )->addresses() );
     if ( dlg->exec() && dlg ) {
-        KPIM::RecentAddresses::self( m_recentAddressConfig )->clear();
-        dlg->addAddresses(m_recentAddressConfig);
-        loadContacts();
+        if (dlg->wasChanged()) {
+            KPIM::RecentAddresses::self( m_recentAddressConfig )->clear();
+            dlg->addAddresses(m_recentAddressConfig);
+            loadContacts();
+        }
     }
 }
 
@@ -231,7 +236,7 @@ void ComposerLineEdit::loadContacts()
     const QString recentAddressGroupName = i18n( "Recent Addresses" );
     if ( MessageComposerSettings::self()->showRecentAddressesInComposer() ){
         const QStringList recent =
-                KPIM::RecentAddresses::self( m_recentAddressConfig )->addresses();
+                cleanupEmailList(KPIM::RecentAddresses::self( m_recentAddressConfig )->addresses());
         QStringList::ConstIterator it = recent.constBegin();
         QString name, email;
 
