@@ -116,6 +116,8 @@ public:
     KProcess *mExtEditorProcess;
     KTemporaryFile *mExtEditorTempFile;
     PimCommon::AutoCorrection *mAutoCorrection;
+private:
+    void canStartProcess(const QString &commandLine);
 };
 
 }
@@ -164,6 +166,10 @@ void KMeditorPrivate::startExternalEditor()
     QStringList command;
     if ( !arg.isEmpty() )
         command<<arg;
+    if (command.isEmpty()) {
+        canStartProcess(commandLine);
+        return;
+    }
     ( *mExtEditorProcess ) << command;
     if ( !filenameAdded ) { // no %f in the editor command
         ( *mExtEditorProcess ) << mExtEditorTempFile->fileName();
@@ -173,14 +179,19 @@ void KMeditorPrivate::startExternalEditor()
                       q, SLOT(slotEditorFinished(int,QProcess::ExitStatus)) );
     mExtEditorProcess->start();
     if ( !mExtEditorProcess->waitForStarted() ) {
-        KMessageBox::error(q->topLevelWidget(),i18n("External editor cannot be started. Please verify command \"%1\"",commandLine));
-        q->killExternalEditor();
-        q->setUseExternalEditor( false );
+        canStartProcess(commandLine);
     } else {
         emit q->externalEditorStarted();
     }
 }
 
+void KMeditorPrivate::canStartProcess(const QString &commandLine)
+{
+    KMessageBox::error(q->topLevelWidget(),i18n("External editor cannot be started. Please verify command \"%1\"",commandLine));
+    q->killExternalEditor();
+    q->setUseExternalEditor( false );
+}
+
 void KMeditorPrivate::slotEditorFinished( int codeError, QProcess::ExitStatus exitStatus )
 {
     if ( exitStatus == QProcess::NormalExit ) {
