@@ -41,14 +41,16 @@
 #endif
 
 namespace MessageViewer {
-EditorWatcher::EditorWatcher( const KUrl & url, const QString &mimeType, bool openWith,
+EditorWatcher::EditorWatcher( const KUrl & url, const QString &mimeType, OpenWithOption option,
                               QObject * parent, QWidget *parentWidget ) :
     QObject( parent ),
     mUrl( url ),
     mMimeType( mimeType ),
-    mOpenWith( openWith ),
+    mInotifyFd(-1),
+    mInotifyWatch(-1),
     mEditor( 0 ),
     mParentWidget( parentWidget ),
+    mOpenWithOption( option ),
     mHaveInotify( false ),
     mFileOpen( false ),
     mEditorRunning( false ),
@@ -60,13 +62,20 @@ EditorWatcher::EditorWatcher( const KUrl & url, const QString &mimeType, bool op
     connect( &mTimer, SIGNAL(timeout()), SLOT(checkEditDone()) );
 }
 
+EditorWatcher::~EditorWatcher()
+{
+#ifdef HAVE_SYS_INOTIFY_H
+    ::close( mInotifyFd );
+#endif
+}
+
 bool EditorWatcher::start()
 {
     // find an editor
     KUrl::List list;
     list.append( mUrl );
     KService::Ptr offer = KMimeTypeTrader::self()->preferredService( mMimeType, QLatin1String("Application") );
-    if ( mOpenWith || !offer ) {
+    if ( (mOpenWithOption == OpenWithDialog) || !offer ) {
         AutoQPointer<KOpenWithDialog> dlg( new KOpenWithDialog( list, i18n("Edit with:"),
                                                                 QString(), mParentWidget ) );
         const int dlgrc = dlg->exec();
@@ -81,7 +90,8 @@ bool EditorWatcher::start()
     // monitor file
     mInotifyFd = inotify_init();
     if ( mInotifyFd > 0 ) {
-        mInotifyWatch = inotify_add_watch( mInotifyFd, mUrl.path().toLatin1(), IN_CLOSE | IN_OPEN | IN_MODIFY );
+        (void)fcntl(mInotifyFd, F_SETFD, FD_CLOEXEC);
+        mInotifyWatch = inotify_add_watch( mInotifyFd, mUrl.path().toLatin1(), IN_CLOSE | IN_OPEN | IN_MODIFY | IN_ATTRIB );
         if ( mInotifyWatch >= 0 ) {
             QSocketNotifier *sn = new QSocketNotifier( mInotifyFd, QSocketNotifier::Read, this );
             connect( sn, SIGNAL(activated(int)), SLOT(inotifyEvent()) );
@@ -108,32 +118,65 @@ bool EditorWatcher::start()
     return true;
 }
 
+bool EditorWatcher::fileChanged() const
+{
+    return mFileModified;
+}
+
+KUrl EditorWatcher::url() const
+{
+    return mUrl;
+}
+
 void EditorWatcher::inotifyEvent()
 {
     assert( mHaveInotify );
+
 #ifdef HAVE_SYS_INOTIFY_H
     int pending = -1;
-    char buffer[4096];
+    int offsetStartRead = 0; // where we read into buffer
+    char buf[8192];
+    assert( mInotifyFd > -1 );
     ioctl( mInotifyFd, FIONREAD, &pending );
+
     while ( pending > 0 ) {
-        int size = read( mInotifyFd, buffer, qMin( pending, (int)sizeof(buffer) ) );
-        pending -= size;
-        if ( size < 0 )
-            break; // error
-        int offset = 0;
-        while ( size > 0 ) {
-            struct inotify_event *event = (struct inotify_event *) &buffer[offset];
-            size -= sizeof( struct inotify_event ) + event->len;
-            offset += sizeof( struct inotify_event ) + event->len;
-            if ( event->mask & IN_OPEN )
+
+        const int bytesToRead = qMin( pending, (int)sizeof( buf ) - offsetStartRead );
+
+        int bytesAvailable = read( mInotifyFd, &buf[offsetStartRead], bytesToRead );
+        pending -= bytesAvailable;
+        bytesAvailable += offsetStartRead;
+        offsetStartRead = 0;
+
+        int offsetCurrent = 0;
+        while ( bytesAvailable >= (int)sizeof( struct inotify_event ) ) {
+            const struct inotify_event * const event = (struct inotify_event *) &buf[offsetCurrent];
+            const int eventSize = sizeof( struct inotify_event ) + event->len;
+            if ( bytesAvailable < eventSize ) {
+                break;
+            }
+
+            bytesAvailable -= eventSize;
+            offsetCurrent += eventSize;
+            if ( event->mask & IN_OPEN ) {
                 mFileOpen = true;
-            if ( event->mask & IN_CLOSE )
+            }
+            if ( event->mask & IN_CLOSE ) {
                 mFileOpen = false;
-            if ( event->mask & IN_MODIFY )
+            }
+            if ( event->mask & (IN_MODIFY|IN_ATTRIB) ) {
                 mFileModified = true;
+            }
+
+        }
+        if (bytesAvailable > 0) {
+            // copy partial event to beginning of buffer
+            memmove(buf, &buf[offsetCurrent], bytesAvailable);
+            offsetStartRead = bytesAvailable;
         }
     }
 #endif
+
     mTimer.start( 500 );
 
 }
