@@ -40,7 +40,10 @@ class MESSAGEVIEWER_EXPORT EditorWatcher : public QObject
 {
     Q_OBJECT
 public:
-
+    enum OpenWithOption {
+        OpenWithDialog,
+        NoOpenWithDialog
+    };
     /**
      * Constructs an EditorWatcher.
      * @param parent the parent object of this EditorWatcher, which will take care of deleting
@@ -48,12 +51,12 @@ public:
      * @param parentWidget the parent widget of this EditorWatcher, which will be used as the parent
      *                     widget for message dialogs.
      */
-    EditorWatcher( const KUrl &url, const QString &mimeType, bool openWith,
+    EditorWatcher( const KUrl &url, const QString &mimeType, OpenWithOption option,
                    QObject *parent, QWidget *parentWidget );
-
+    ~EditorWatcher();
     bool start();
-    bool fileChanged() const { return mFileModified; }
-    KUrl url() const { return mUrl;}
+    bool fileChanged() const;
+    KUrl url() const;
 signals:
     void editDone( MessageViewer::EditorWatcher* watcher );
 
@@ -65,22 +68,20 @@ private slots:
 private:
     KUrl mUrl;
     QString mMimeType;
-    bool mOpenWith;
-    KProcess *mEditor;
-    QWidget *mParentWidget;
-
-    int mInotifyFd;
-    int mInotifyWatch;
-    bool mHaveInotify;
-
-    bool mFileOpen;
-    bool mEditorRunning;
-
-    bool mFileModified;
-
     QTimer mTimer;
     QTime mEditTime;
 
+    int mInotifyFd;
+    int mInotifyWatch;
+
+    KProcess *mEditor;
+    QWidget *mParentWidget;
+
+    OpenWithOption mOpenWithOption;
+    bool mHaveInotify;
+    bool mFileOpen;
+    bool mEditorRunning;
+    bool mFileModified;
     bool mDone;
 };
 
