@@ -18,7 +18,6 @@
 #include "createnewnotejob.h"
 #include "notesharedglobalconfig.h"
 #include "noteshared/attributes/showfoldernotesattribute.h"
-#include "noteshared/settings/globalsettings.h"
 #include "dialog/selectednotefolderdialog.h"
 
 #include "akonadi_next/note.h"
@@ -81,7 +80,6 @@ void CreateNewNoteJob::createFetchCollectionJob(bool useSettings)
         id = NoteShared::NoteSharedGlobalConfig::self()->defaultFolder();
     } else {
         NoteShared::NoteSharedGlobalConfig::self()->setDefaultFolder(id);
-        NoteShared::GlobalSettings::self()->requestSync();
     }
     if (id == -1) {
         QPointer<SelectedNotefolderDialog> dlg = new SelectedNotefolderDialog(mWidget);
@@ -93,12 +91,13 @@ void CreateNewNoteJob::createFetchCollectionJob(bool useSettings)
         }
         if (dlg->useFolderByDefault()) {
             NoteShared::NoteSharedGlobalConfig::self()->setDefaultFolder(col.id());
-            NoteShared::GlobalSettings::self()->requestSync();
+            NoteShared::NoteSharedGlobalConfig::self()->writeConfig();
         }
         delete dlg;
     } else {
         col = Akonadi::Collection(id);
     }
+    NoteShared::NoteSharedGlobalConfig::self()->writeConfig();
     Akonadi::CollectionFetchJob *fetchCollection = new Akonadi::CollectionFetchJob( col, Akonadi::CollectionFetchJob::Base );
     connect(fetchCollection, SIGNAL(result(KJob*)), this, SLOT(slotFetchCollection(KJob*)));
 }
@@ -181,7 +180,7 @@ void CreateNewNoteJob::slotNoteCreationFinished(KJob *job)
     if (job->error()) {
         kWarning() << job->errorString();
         NoteShared::NoteSharedGlobalConfig::self()->setDefaultFolder(-1);
-        NoteShared::GlobalSettings::self()->requestSync();
+        NoteShared::NoteSharedGlobalConfig::self()->writeConfig();
         KMessageBox::error(mWidget, i18n("Note was not created."), i18n("Create new note"));
     }
     deleteLater();
