@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -230,7 +230,7 @@ void AutoCorrectionTest::shouldNotReplaceUppercaseLetter()
     QCOMPARE(doc.toPlainText(), text);
 }
 
-void AutoCorrectionTest::shouldReplaceToBold()
+void AutoCorrectionTest::shouldReplaceToTextFormat()
 {
     PimCommon::AutoCorrection autocorrection;
     autocorrection.setEnabledAutoCorrection(true);
@@ -250,17 +250,44 @@ void AutoCorrectionTest::shouldReplaceToBold()
     autocorrection.autocorrect(true, doc, position);
     QCOMPARE(doc.toPlainText(), result);
 
+
+    text = QLatin1String("*foo*");
+    doc.setHtml(text);
+    position = text.length();
+    autocorrection.autocorrect(true, doc, position);
+    QCOMPARE(doc.toPlainText(), result);
+    QTextCursor cursor(&doc);
+    cursor.setPosition(2);
+    QTextCharFormat charFormat = cursor.charFormat();
+    QCOMPARE(charFormat.font().underline(), false);
+    QCOMPARE(charFormat.font().bold(), true);
+    QCOMPARE(charFormat.font().strikeOut(), false);
+
+
+
     text = QLatin1String("_foo_");
     doc.setHtml(text);
     position = text.length();
     autocorrection.autocorrect(true, doc, position);
     QCOMPARE(doc.toPlainText(), result);
+    cursor = QTextCursor(&doc);
+    cursor.setPosition(2);
+    charFormat = cursor.charFormat();
+    QCOMPARE(charFormat.font().underline(), true);
+    QCOMPARE(charFormat.font().bold(), false);
+    QCOMPARE(charFormat.font().strikeOut(), false);
 
     text = QLatin1String("-foo-");
     doc.setHtml(text);
     position = text.length();
     autocorrection.autocorrect(true, doc, position);
     QCOMPARE(doc.toPlainText(), result);
+    cursor = QTextCursor(&doc);
+    cursor.setPosition(2);
+    charFormat = cursor.charFormat();
+    QCOMPARE(charFormat.font().underline(), false);
+    QCOMPARE(charFormat.font().bold(), false);
+    QCOMPARE(charFormat.font().strikeOut(), true);
 
     //Don't convert it.
     text = QLatin1String("-foo1");
