@@ -41,20 +41,38 @@ public:
     void editScript();
     void desactivateScript();
     void refreshList();
-    void saveScript();
+    void uploadScript();
     bool needToSaveScript();
 
     KTabWidget *tabWidget() const;
 
     KSieveUi::SieveEditorWidget::EditorMode pageMode() const;
+    bool isUndoAvailable() const;
+    bool isRedoAvailable() const;
+
+    bool hasSelection() const;
 public Q_SLOTS:
     void slotGoToLine();
 
+    void slotReplace();
+    void slotFind();
+    void slotCopy();
+    void slotPaste();
+    void slotCut();
+    void slotSaveAs();
+    void slotCheckSpelling();
+    void slotShare();
+    void slotImport();
+
 Q_SIGNALS:
     void updateButtons(bool newScriptAction, bool editScriptAction, bool deleteScriptAction, bool desactivateScriptAction);
     void updateScriptList();
     void modeEditorChanged(KSieveUi::SieveEditorWidget::EditorMode);
     void serverSieveFound(bool);
+    void undoAvailable(bool);
+    void redoAvailable(bool);
+    void copyAvailable(bool);
+
 
 private slots:
     void slotCreateScriptPage(const KUrl &url, const QStringList &capabilities, bool isNewScript);
@@ -63,7 +81,11 @@ private slots:
     void slotGeneralPaletteChanged();
     void slotTabCloseRequested(int index);
     void slotTabRemoveAllExclude(int index);
+    void slotUndo();
+    void slotRedo();
+    void slotSelectAll();
 private:
+
     QWidget *hasExistingPage(const KUrl &url);
     QColor mModifiedScriptColor;
     QColor mScriptColor;
