@@ -40,17 +40,36 @@ public:
     void loadScript(const KUrl &url, const QStringList &capabilities);
     KUrl currentUrl() const;
     void setIsNewScript(bool isNewScript);
-    void saveScript(bool showInformation = true, bool forceSave = false);
+    void uploadScript(bool showInformation = true, bool forceSave = false);
     bool needToSaveScript();
 
     bool isModified() const;
     void goToLine();
     KSieveUi::SieveEditorWidget::EditorMode pageMode() const;
 
+    void find();
+    void replace();
+    void redo();
+    void undo();
+    bool isUndoAvailable() const;
+    bool isRedoAvailable() const;
+    void paste();
+    void cut();
+    void copy();
+    bool hasSelection() const;
+
+    void selectAll();
+    void saveAs();
+    void checkSpelling();
+    void share();
+    void import();
 Q_SIGNALS:
     void refreshList();
     void scriptModified(bool, SieveEditorPageWidget *);
     void modeEditorChanged(KSieveUi::SieveEditorWidget::EditorMode);
+    void undoAvailable(bool);
+    void redoAvailable(bool);
+    void copyAvailable(bool);
 
 private slots:
     void slotGetResult(KManageSieve::SieveJob *, bool success, const QString &script, bool isActive);
